# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asvprotobuf/sensor.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from asvprotobuf import std_pb2 as asvprotobuf_dot_std__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='asvprotobuf/sensor.proto',
  package='asvprotobuf.sensor',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x18\x61svprotobuf/sensor.proto\x12\x12\x61svprotobuf.sensor\x1a\x15\x61svprotobuf/std.proto\"\x90\x02\n\x03Imu\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12\x31\n\x0borientation\x18\x0f \x01(\x0b\x32\x1c.asvprotobuf.std.Orientation\x12\x31\n\x10\x61ngular_velocity\x18\x10 \x01(\x0b\x32\x17.asvprotobuf.std.Vector\x12-\n\x0c\x61\x63\x63\x65leration\x18\x11 \x01(\x0b\x32\x17.asvprotobuf.std.Vector\x12\x36\n\x15\x61\x63\x63\x65leration_variance\x18\x13 \x01(\x0b\x32\x17.asvprotobuf.std.Vector\x12\x13\n\x0btemperature\x18\x12 \x01(\x01\"\x85\x02\n\x06GPSFix\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12\x31\n\x06status\x18\x13 \x01(\x0e\x32!.asvprotobuf.sensor.GPSFix.Status\x12\x10\n\x08latitude\x18\x0f \x01(\x01\x12\x11\n\tlongitude\x18\x10 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x11 \x01(\x01\x12\x32\n\x11linear_velocities\x18\x12 \x01(\x0b\x32\x17.asvprotobuf.std.Vector\"4\n\x06Status\x12\t\n\x05NOFIX\x10\x00\x12\t\n\x05UAFIX\x10\x01\x12\t\n\x05SBFIX\x10\x02\x12\t\n\x05GBFIX\x10\x03\"b\n\x08GPSError\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12\x14\n\x0c\x65rror_radius\x18\x0f \x01(\x01\x12\x17\n\x0flongitude_error\x18\x10 \x01(\x01\"\xa4\x01\n\x05Image\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12\x30\n\x06\x66ormat\x18\x0f \x01(\x0e\x32 .asvprotobuf.sensor.Image.Format\x12\r\n\x05image\x18\x10 \x01(\t\"1\n\x06\x46ormat\x12\x07\n\x03PNG\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x08\n\x04WEBP\x10\x02\x12\n\n\x06\x42INARY\x10\x03\"\xbe\x01\n\tLaserScan\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12\x11\n\tangle_min\x18\x11 \x01(\x01\x12\x11\n\tangle_max\x18\x12 \x01(\x01\x12\x17\n\x0f\x61ngle_increment\x18\x13 \x01(\x01\x12\x11\n\trange_min\x18\x14 \x01(\x01\x12\x11\n\trange_max\x18\x15 \x01(\x01\x12\x0e\n\x06ranges\x18\x0f \x03(\x01\x12\x13\n\x0bintensities\x18\x10 \x03(\x01\x62\x06proto3')
  ,
  dependencies=[asvprotobuf_dot_std__pb2.DESCRIPTOR,])



_GPSFIX_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='asvprotobuf.sensor.GPSFix.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOFIX', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UAFIX', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SBFIX', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GBFIX', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=556,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_GPSFIX_STATUS)

_IMAGE_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='asvprotobuf.sensor.Image.Format',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PNG', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=826,
  serialized_end=875,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_FORMAT)


_IMU = _descriptor.Descriptor(
  name='Imu',
  full_name='asvprotobuf.sensor.Imu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.sensor.Imu.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='asvprotobuf.sensor.Imu.orientation', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='asvprotobuf.sensor.Imu.angular_velocity', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='asvprotobuf.sensor.Imu.acceleration', index=3,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acceleration_variance', full_name='asvprotobuf.sensor.Imu.acceleration_variance', index=4,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='asvprotobuf.sensor.Imu.temperature', index=5,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=344,
)


_GPSFIX = _descriptor.Descriptor(
  name='GPSFix',
  full_name='asvprotobuf.sensor.GPSFix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.sensor.GPSFix.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='asvprotobuf.sensor.GPSFix.status', index=1,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='asvprotobuf.sensor.GPSFix.latitude', index=2,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='asvprotobuf.sensor.GPSFix.longitude', index=3,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='asvprotobuf.sensor.GPSFix.altitude', index=4,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linear_velocities', full_name='asvprotobuf.sensor.GPSFix.linear_velocities', index=5,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GPSFIX_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=608,
)


_GPSERROR = _descriptor.Descriptor(
  name='GPSError',
  full_name='asvprotobuf.sensor.GPSError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.sensor.GPSError.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_radius', full_name='asvprotobuf.sensor.GPSError.error_radius', index=1,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude_error', full_name='asvprotobuf.sensor.GPSError.longitude_error', index=2,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=708,
)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='asvprotobuf.sensor.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.sensor.Image.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='asvprotobuf.sensor.Image.format', index=1,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='asvprotobuf.sensor.Image.image', index=2,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGE_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=875,
)


_LASERSCAN = _descriptor.Descriptor(
  name='LaserScan',
  full_name='asvprotobuf.sensor.LaserScan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.sensor.LaserScan.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle_min', full_name='asvprotobuf.sensor.LaserScan.angle_min', index=1,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle_max', full_name='asvprotobuf.sensor.LaserScan.angle_max', index=2,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle_increment', full_name='asvprotobuf.sensor.LaserScan.angle_increment', index=3,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_min', full_name='asvprotobuf.sensor.LaserScan.range_min', index=4,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_max', full_name='asvprotobuf.sensor.LaserScan.range_max', index=5,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ranges', full_name='asvprotobuf.sensor.LaserScan.ranges', index=6,
      number=15, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intensities', full_name='asvprotobuf.sensor.LaserScan.intensities', index=7,
      number=16, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=1068,
)

_IMU.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_IMU.fields_by_name['orientation'].message_type = asvprotobuf_dot_std__pb2._ORIENTATION
_IMU.fields_by_name['angular_velocity'].message_type = asvprotobuf_dot_std__pb2._VECTOR
_IMU.fields_by_name['acceleration'].message_type = asvprotobuf_dot_std__pb2._VECTOR
_IMU.fields_by_name['acceleration_variance'].message_type = asvprotobuf_dot_std__pb2._VECTOR
_GPSFIX.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_GPSFIX.fields_by_name['status'].enum_type = _GPSFIX_STATUS
_GPSFIX.fields_by_name['linear_velocities'].message_type = asvprotobuf_dot_std__pb2._VECTOR
_GPSFIX_STATUS.containing_type = _GPSFIX
_GPSERROR.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_IMAGE.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_IMAGE.fields_by_name['format'].enum_type = _IMAGE_FORMAT
_IMAGE_FORMAT.containing_type = _IMAGE
_LASERSCAN.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
DESCRIPTOR.message_types_by_name['Imu'] = _IMU
DESCRIPTOR.message_types_by_name['GPSFix'] = _GPSFIX
DESCRIPTOR.message_types_by_name['GPSError'] = _GPSERROR
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['LaserScan'] = _LASERSCAN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Imu = _reflection.GeneratedProtocolMessageType('Imu', (_message.Message,), dict(
  DESCRIPTOR = _IMU,
  __module__ = 'asvprotobuf.sensor_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.sensor.Imu)
  ))
_sym_db.RegisterMessage(Imu)

GPSFix = _reflection.GeneratedProtocolMessageType('GPSFix', (_message.Message,), dict(
  DESCRIPTOR = _GPSFIX,
  __module__ = 'asvprotobuf.sensor_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.sensor.GPSFix)
  ))
_sym_db.RegisterMessage(GPSFix)

GPSError = _reflection.GeneratedProtocolMessageType('GPSError', (_message.Message,), dict(
  DESCRIPTOR = _GPSERROR,
  __module__ = 'asvprotobuf.sensor_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.sensor.GPSError)
  ))
_sym_db.RegisterMessage(GPSError)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'asvprotobuf.sensor_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.sensor.Image)
  ))
_sym_db.RegisterMessage(Image)

LaserScan = _reflection.GeneratedProtocolMessageType('LaserScan', (_message.Message,), dict(
  DESCRIPTOR = _LASERSCAN,
  __module__ = 'asvprotobuf.sensor_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.sensor.LaserScan)
  ))
_sym_db.RegisterMessage(LaserScan)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asvprotobuf/std.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='asvprotobuf/std.proto',
  package='asvprotobuf.std',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x15\x61svprotobuf/std.proto\x12\x0f\x61svprotobuf.std\"+\n\tTimestamp\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"E\n\x06Header\x12)\n\x05stamp\x18\x01 \x01(\x0b\x32\x1a.asvprotobuf.std.Timestamp\x12\x10\n\x08\x66rame_id\x18\x0f \x01(\t\"7\n\x0bOrientation\x12\x0c\n\x04roll\x18\x0f \x01(\x01\x12\r\n\x05pitch\x18\x10 \x01(\x01\x12\x0b\n\x03yaw\x18\x11 \x01(\x01\")\n\x06Vector\x12\t\n\x01x\x18\x0f \x01(\x01\x12\t\n\x01y\x18\x10 \x01(\x01\x12\t\n\x01z\x18\x11 \x01(\x01\x62\x06proto3')
)




_TIMESTAMP = _descriptor.Descriptor(
  name='Timestamp',
  full_name='asvprotobuf.std.Timestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='asvprotobuf.std.Timestamp.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='asvprotobuf.std.Timestamp.nanos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=85,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='asvprotobuf.std.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='asvprotobuf.std.Header.stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='asvprotobuf.std.Header.frame_id', index=1,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=156,
)


_ORIENTATION = _descriptor.Descriptor(
  name='Orientation',
  full_name='asvprotobuf.std.Orientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roll', full_name='asvprotobuf.std.Orientation.roll', index=0,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='asvprotobuf.std.Orientation.pitch', index=1,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yaw', full_name='asvprotobuf.std.Orientation.yaw', index=2,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=213,
)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='asvprotobuf.std.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='asvprotobuf.std.Vector.x', index=0,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='asvprotobuf.std.Vector.y', index=1,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='asvprotobuf.std.Vector.z', index=2,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=256,
)

_HEADER.fields_by_name['stamp'].message_type = _TIMESTAMP
DESCRIPTOR.message_types_by_name['Timestamp'] = _TIMESTAMP
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Orientation'] = _ORIENTATION
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), dict(
  DESCRIPTOR = _TIMESTAMP,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Timestamp)
  ))
_sym_db.RegisterMessage(Timestamp)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Header)
  ))
_sym_db.RegisterMessage(Header)

Orientation = _reflection.GeneratedProtocolMessageType('Orientation', (_message.Message,), dict(
  DESCRIPTOR = _ORIENTATION,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Orientation)
  ))
_sym_db.RegisterMessage(Orientation)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), dict(
  DESCRIPTOR = _VECTOR,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Vector)
  ))
_sym_db.RegisterMessage(Vector)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import os

if (sys.version_info.major!=3):
    raise SystemError("Python version 2 is installed. Please use Python 3.")

if (sys.platform=="linux" or sys.platform=="linux2"):
    #Check for installation type
    import distro
    if(distro.id()=="ubuntu" or distro.id()=="debian"):
        protobuf_installed = 0==os.system("sudo apt-get install -y protobuf-compiler")
        print(protobuf_installed)
        if(not protobuf_installed):
            raise SystemError("Could not install Protobuf on your system.")
        base_path = os.getcwd()
        message_installed =  0==os.system("protoc --python_out='%s' asvprotobuf/std.proto" % (base_path))
        if(not message_installed):
            raise SystemError("Could not generate protobuf implementation files.")
    #Need to add more operating systems

elif (sys.platform=="darwin"):
    #Brew installation
    brew_installed = 0==os.system("which brew")
    if (not brew_installed):
        print("Homebrew is not installed on your system, installing Homebrew.")
        brew_install = 0==os.system("/usr/bin/ruby -e '$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)'")
        if(not brew_install):
            raise SystemError("Cannot install Homebrew on your system.")

    protobuf_installed = 0==os.system("which protoc")
    if(not protobuf_installed):
        os.system("brew install protobuf --with-python --without-python@2")

    base_path = os.getcwd()
    message_installed =  0==os.system("protoc -I %s --python_out='%s' asvprotobuf/*.proto" % (base_path,base_path))
    if(not message_installed):
        raise SystemError("Could not generate protobuf implementation files.")

else:
    raise SystemError("This package cannot be install on Windows or Cygwin.")

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup

readme = open("README.md", "r").read()

import asvprotobuf
version = asvprotobuf.__version__

setup(
    name="asvprotobuf",
    version=version,
    description="ASV API for using protobuf for serialization and deserialization of objects for Inter Process Communication",
    long_description=readme,
    long_description_content_type='text/markdown',
    author="Akash Purandare",
    author_email="akash.p1997@gmail.com",
    url="https://github.com/akashp1997/asvprotobuf",
    packages=["asvprotobuf"],
    include_package_data=True,
    install_requires=["protobuf>=3.6.1"],
    license="BSD-3-Clause",
    zip_safe=True,
    keywords="asvprotobuf"
)
